@@ -227,20 +227,24 @@ def test_sign_up(client_session):
 
     # check that we catch a flash error if we try to sign-up with an identical
     # username
-    user_profile = {'user_name': 'xx', 'password': 'xx',
-                    'firstname': 'xx', 'lastname': 'xx',
-                    'email': 'test_user@gmail.com'}
-    _assert_flash('/sign_up', data=user_profile,
-                  message='username is already in use')
+    user_profile = {
+        "user_name": "xx",
+        "password": "xx",
+        "firstname": "xx",
+        "lastname": "xx",
+        "email": "test_user@gmail.com",
+    }
+    _assert_flash("/sign_up", data=user_profile, message="username is already in use")
 
-    user_profile.update(user_name='new', email="yy")
-    _assert_flash('/sign_up', data=user_profile,
-                  message='email is already in use')
+    user_profile.update(user_name="new", email="yy")
+    _assert_flash("/sign_up", data=user_profile, message="email is already in use")
 
-    user_profile.update(user_name='yy', email="yy")
-    _assert_flash('/sign_up', data=user_profile,
-                  message=("username is already in use "
-                           "and email is already in use"))
+    user_profile.update(user_name="yy", email="yy")
+    _assert_flash(
+        "/sign_up",
+        data=user_profile,
+        message=("username is already in use and email is already in use"),
+    )
 
 
 @_fail_no_smtp_server
@@ -260,6 +264,8 @@ def test_sign_up_with_approval(client_session):
                 flash_message = dict(cs['_flashes'])
             assert 'We sent a confirmation email.' in flash_message['message']
             # check that the email has been sent
+            # shutdown the threadpool and wait for the future (email) to be sent
+            client.application.pool.shutdown(wait=True)
             assert len(outbox) == 1
             assert ('Click on the following link to confirm your email'
                     in outbox[0].body)
@@ -289,6 +295,8 @@ def test_sign_up_with_approval(client_session):
             assert ('An email has been sent to the RAMP administrator' in
                     flash_message['message'])
             # check that we send an email to the administrator
+            # shutdown the threadpool and wait for the future (email) to be sent
+            client.application.pool.shutdown(wait=True)
             assert len(outbox) == 1
             assert "Approve registration of new_user_1" in outbox[0].subject
             # ensure that we have the last changes
@@ -393,17 +401,11 @@ def test_reset_password(client_session):
     # set back the account to 'user' access level
     user.access_level = 'user'
     session.commit()
-    rv = client.post('/reset_password', data={'email': user.email})
-    with client.session_transaction() as cs:
-        flash_message = dict(cs['_flashes'])
-    assert flash_message['message'] == ('An email to reset your password has '
-                                        'been sent')
-    assert rv.status_code == 302
-    assert rv.location == 'http://localhost/login'
-
     with client.application.app_context():
         with mail.record_messages() as outbox:
-            rv = client.post('/reset_password', data={'email': user.email})
+            rv = client.post("/reset_password", data={"email": user.email})
+            # shutdown the threadpool and wait for the future (email) to be sent
+            client.application.pool.shutdown(wait=True)
             assert len(outbox) == 1
             assert 'click on the link to reset your password' in outbox[0].body
             # get the link to reset the password
@@ -416,6 +418,13 @@ def test_reset_password(client_session):
                 reset_password_link.find('/reset'):
             ]
 
+    rv = client.post("/reset_password", data={"email": user.email})
+    with client.session_transaction() as cs:
+        flash_message = dict(cs["_flashes"])
+    assert flash_message["message"] == ("An email to reset your password has been sent")
+    assert rv.status_code == 302
+    assert rv.location == "http://localhost/login"
+
     # check that we can reset the password using the previous link
     # GET method
     rv = client.get(reset_password_link)
@@ -446,7 +455,9 @@ def test_reset_token_error(client_session):
     user = get_user_by_name(session, 'test_user')
     with client.application.app_context():
         with mail.record_messages() as outbox:
-            rv = client.post('/reset_password', data={'email': user.email})
+            rv = client.post("/reset_password", data={"email": user.email})
+            # shutdown the threadpool and wait for the future (email) to be sent
+            client.application.pool.shutdown(wait=True)
             assert len(outbox) == 1
             assert 'click on the link to reset your password' in outbox[0].body
             # get the link to reset the password
