@@ -345,6 +345,8 @@ def test_sign_up_for_event_mail(client_session):
                 assert rv.status_code == 302
                 session.commit()
                 # check that the email has been sent
+                # shutdown the threadpool and wait for the future (email) to be sent
+                client.application.pool.shutdown(wait=True)
                 assert len(outbox) == 1
                 assert ('Click on this link to approve the sign-up request'
                         in outbox[0].body)
@@ -407,6 +409,8 @@ def test_ask_for_event_mail(client_session):
                 rv = client.post('problems/iris/ask_for_event', data=data)
                 assert rv.status_code == 302
                 # check that the email has been sent
+                # shutdown the threadpool and wait for the future (email) to be sent
+                client.application.pool.shutdown(wait=True)
                 assert len(outbox) == 1
                 assert ('User test_user asked to add a new event'
                         in outbox[0].body)
