@@ -13,6 +13,7 @@ from bokeh.embed import components
 import flask_login
 
 from flask import Blueprint
+from flask import copy_current_request_context
 from flask import current_app as app
 from flask import redirect
 from flask import render_template
@@ -256,21 +257,26 @@ def sign_up_for_event(event_name):
 
     ask_sign_up_team(db.session, event.name, flask_login.current_user.name)
     if event.is_controled_signup:
-        admin_users = User.query.filter_by(access_level='admin')
+        admin_users = User.query.filter_by(access_level="admin")
+        send_mail_with_context = copy_current_request_context(send_mail)
         for admin in admin_users:
             subject = ('Request to sign-up {} to RAMP event {}'
                        .format(event.name, flask_login.current_user.name))
             body = body_formatter_user(flask_login.current_user)
-            url_approve = ('http://{}/events/{}/sign_up/{}'
-                           .format(
-                               app.config['DOMAIN_NAME'], event.name,
-                               flask_login.current_user.name
-                           ))
-            body += ('Click on this link to approve the sign-up request: {}'
-                     .format(url_approve))
-            send_mail(admin.email, subject, body)
-        return redirect_to_user("Sign-up request is sent to event admins.",
-                                is_error=False, category='Request sent')
+            url_approve = "http://{}/events/{}/sign_up/{}".format(
+                app.config["DOMAIN_NAME"],
+                event.name,
+                flask_login.current_user.name,
+            )
+            body += "Click on this link to approve the sign-up request: {}".format(
+                url_approve
+            )
+            send_mail_with_context(admin.email, subject, body)
+        return redirect_to_user(
+            "Sign-up request is sent to event admins.",
+            is_error=False,
+            category="Request sent",
+        )
     sign_up_team(db.session, event.name, flask_login.current_user.name)
     return redirect_to_sandbox(
         event,
@@ -532,7 +538,8 @@ def sandbox(event_name):
                         .format(flask_login.current_user.name,
                                 new_submission.name, event_team))
             if event.is_send_submitted_mails:
-                admin_users = User.query.filter_by(access_level='admin')
+                admin_users = User.query.filter_by(access_level="admin")
+                send_mail_with_context = copy_current_request_context(send_mail)
                 for admin in admin_users:
                     subject = 'Submission {} sent for training'.format(
                         new_submission.name
@@ -542,11 +549,14 @@ def sandbox(event_name):
                     user: {}
                     submission: {}
                     submission path: {}
-                    """.format(event_team.event.name,
-                               flask_login.current_user.name,
-                               new_submission.name, new_submission.path)
-                    send_mail(admin.email, subject, body)
-            if app.config['TRACK_USER_INTERACTION']:
+                    """.format(
+                        event_team.event.name,
+                        flask_login.current_user.name,
+                        new_submission.name,
+                        new_submission.path,
+                    )
+                    send_mail_with_context(admin.email, subject, body)
+            if app.config["TRACK_USER_INTERACTION"]:
                 add_user_interaction(
                     db.session,
                     interaction='submit',
@@ -599,7 +609,8 @@ def ask_for_event(problem_name):
         min_duration_between_submissions_second=0,
     )
     if form.validate_on_submit():
-        admin_users = User.query.filter_by(access_level='admin')
+        admin_users = User.query.filter_by(access_level="admin")
+        send_mail_with_context = copy_current_request_context(send_mail)
         for admin in admin_users:
             subject = 'Request to add a new event'
             body = """User {} asked to add a new event:
@@ -620,7 +631,7 @@ def ask_for_event(problem_name):
                 form.opening_date.data,
                 form.closing_date.data
             )
-            send_mail(admin.email, subject, body)
+            send_mail_with_context(admin.email, subject, body)
         return redirect_to_user(
             'Thank you. Your request has been sent to RAMP administrators.',
             category='Event request', is_error=False
@@ -869,9 +880,11 @@ def view_model(submission_hash, f_name):
             )
 
         return send_from_directory(
-            submission_abspath, f_name, as_attachment=True,
-            attachment_filename='{}_{}'.format(submission.hash_[:6], f_name),
-            mimetype='application/octet-stream'
+            submission_abspath,
+            f_name,
+            as_attachment=True,
+            download_name="{}_{}".format(submission.hash_[:6], f_name),
+            mimetype="application/octet-stream",
         )
 
     # Importing selected files into sandbox
@@ -1033,6 +1046,6 @@ def download_submission(submission_hash):
     file_in_memory.seek(0)
     return send_file(
         file_in_memory,
-        attachment_filename=f"submission_{submission.id}.zip",
+        download_name=f"submission_{submission.id}.zip",
         as_attachment=True,
     )
